@@ -1,11 +1,11 @@
 # $File: //depot/OurNet-BBS/BBS/NNTP/Board.pm $ $Author: autrijus $
-# $Revision: #5 $ $Change: 1531 $ $DateTime: 2001/08/18 01:03:39 $
+# $Revision: #6 $ $Change: 1897 $ $DateTime: 2001/09/24 19:12:48 $
 
 package OurNet::BBS::NNTP::Board;
 
 use strict;
 use fields qw/nntp board _ego _hash/;
-use OurNet::BBS;
+use OurNet::BBS::Base;
 
 sub refresh_articles {
     my $self = shift;
