@@ -1,11 +1,10 @@
 # $File: //depot/OurNet-BBS/BBS/PTT/User.pm $ $Author: autrijus $
-# $Revision: #2 $ $Change: 1134 $ $DateTime: 2001/06/14 18:08:06 $
+# $Revision: #3 $ $Change: 1525 $ $DateTime: 2001/08/17 22:49:33 $
 
 package OurNet::BBS::PTT::User;
 
 use base qw/OurNet::BBS::MAPLE2::User/;
-use fields qw/_cache/;
-
-BEGIN { __PACKAGE__->initvars() }
+use fields qw/_ego _hash/;
+use OurNet::BBS::Base;
 
 1;
